@@ -1,5 +1,5 @@
 package App::Oozie::Deploy::Template;
-$App::Oozie::Deploy::Template::VERSION = '0.012';
+$App::Oozie::Deploy::Template::VERSION = '0.013';
 use 5.014;
 use strict;
 use warnings;
@@ -509,7 +509,7 @@ sub _pre_process_ttconfig_into_tempfile {
     my $opt    = shift || {};
     my $logger = $self->logger;
 
-    my($fh_tmp_cfg, $tmp_cfg_file) = File::Temp::tempfile( undef, DIR => resolve_tmp_dir() );
+    my($fh_tmp_cfg, $tmp_cfg_file) = File::Temp::tempfile( '', DIR => resolve_tmp_dir() );
 
     my $file = File::Spec->catfile( $self->ttlib_base_dir, 'ttree.cfg' );
     open my $FH, '<', $file or die "Failed to read $file: $!";
@@ -555,7 +555,7 @@ App::Oozie::Deploy::Template
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
